translate.search.segment

Package translate :: Package search :: Module segment |
[hide private]
[frames] | no frames]

# Module segment

source code

Module to deal with different types and uses of segmentation

Functions | [hide private]
character_iter(text) Returns an iterator over the characters in text. | source code
characters(text) Returns a list of characters in text. | source code
word_iter(text) Returns an iterator over the words in text. | source code
words(text) Returns a list of words in text. | source code
sentence_iter(text) Returns an iterator over the senteces in text. | source code
sentences(text) Returns a list of senteces in text. | source code

Variables | [hide private]
| punctuation = ``u'``.,;:!?-@#$%^*_()[]{}/\'"<>‘’‚‛“”„‟′″‴‵‶‷‹›«»±³``...``
| __package__ = `None` hash(x)

Variables Details | [hide private]

  ### punctuation Value:
      u'.,;:!?-@#$%^*_()[]{}/\'"<>‘’‚‛“”„‟′″‴‵‶‷‹›«»±³¹²°¿©®×£¥'